@@ -4,12 +4,13 @@
 
 #' @title Compute barycentric coordinates
 #'
-#' @description Identify knot intervals or triangles and compute barycentric coordinates
+#' @description Identify knot intervals or triangles and compute barycentric
+#'   coordinates
 #'
 #' @param mesh `fm_mesh_1d` or `fm_mesh_2d` object
 #' @param loc Points for which to identify the containing interval/triangle, and
-#' corresponding barycentric coordinates. May be a vector (for 1d) or a matrix
-#' of raw coordinates, `sf`, or `sp` point information (for 2d).
+#'   corresponding barycentric coordinates. May be a vector (for 1d) or a matrix
+#'   of raw coordinates, `sf`, or `sp` point information (for 2d).
 #' @param \dots Arguments forwarded to sub-methods.
 #' @returns A list with elements `t`; either
 #' \itemize{
@@ -46,12 +47,11 @@ do.the.split <- function(knots, loc) {
 
 
 
-#' @describeIn fm_bary Return a list with elements
-#' `t` (start and endpoint knot indices) and `bary` (barycentric coordinates), both
-#' 2-column matrices.
+#' @describeIn fm_bary Return a list with elements `t` (start and endpoint knot
+#'   indices) and `bary` (barycentric coordinates), both 2-column matrices.
 #'
-#' For `method = "nearest"`, `t[,1]` contains the index of the nearest mesh knot,
-#' and each row of `bary` contains `c(1, 0)`.
+#' For `method = "nearest"`, `t[,1]` contains the index of the nearest mesh
+#' knot, and each row of `bary` contains `c(1, 0)`.
 #' @param method character; method for defining the barycentric coordinates,
 #' "linear" (default) or "nearest"
 #' @param restricted logical, used for `method="linear"`.
@@ -112,12 +112,25 @@ fm_bary.fm_mesh_1d <- function(mesh,
 
 #' @param crs Optional crs information for `loc`
 #'
-#' @describeIn fm_bary A list with elements `t` (vector of triangle indices) and `bary`
-#' (3-column matrix of barycentric coordinates). Points that were not found
-#' give `NA` entries in `t` and `bary`.
+#' @describeIn fm_bary A list with elements `t` (vector of triangle indices) and
+#'   `bary` (3-column matrix of barycentric coordinates). Points that were not
+#'   found give `NA` entries in `t` and `bary`.
+#' @param max_batch_size integer; maximum number of points to process in a
+#'   single batch. This speeds up calculations by avoiding repeated large
+#'   internal memory allocations and data copies. The default, `NULL`, uses
+#'   `max_batch_size = 2e5L`, chosen based on empirical time measurements to
+#'   give an approximately optimal runtime.
 #'
 #' @export
-fm_bary.fm_mesh_2d <- function(mesh, loc, crs = NULL, ...) {
+fm_bary.fm_mesh_2d <- function(mesh,
+                               loc,
+                               crs = NULL,
+                               ...,
+                               max_batch_size = NULL) {
+  if (is.null(max_batch_size)) {
+    max_batch_size <- 2e5L
+  }
+
   loc <- fm_onto_mesh(mesh, loc, crs = crs)
 
   # Avoid sphere accuracy issues by scaling to unit sphere
@@ -133,7 +146,7 @@ fm_bary.fm_mesh_2d <- function(mesh, loc, crs = NULL, ...) {
       nrow = nrow(loc),
       ncol = ncol(loc)
     )) == 0)
-  if (length(pre_ok_idx) <= 2e5) {
+  if (length(pre_ok_idx) <= max_batch_size) {
     result <- fmesher_bary(
       mesh_loc = mesh$loc * scale,
       mesh_tv = mesh$graph$tv - 1L,
@@ -148,7 +161,7 @@ fm_bary.fm_mesh_2d <- function(mesh, loc, crs = NULL, ...) {
   } else {
     tri <- rep(NA_integer_, nrow(loc))
     bary <- matrix(NA_real_, nrow(loc), 3)
-    n_batches <- ceiling(length(pre_ok_idx) / 2e5)
+    n_batches <- ceiling(length(pre_ok_idx) / max_batch_size)
     batch_idx <- round(seq(0, length(pre_ok_idx), length.out = n_batches + 1))
     subindex <- split(pre_ok_idx, rep(seq_len(n_batches), diff(batch_idx)))
     for (k in seq_along(subindex)) {
