@@ -19,7 +19,7 @@ fm_fem <- function(mesh, order = 2, ...) {
 }
 
 #' @rdname fm_fem
-#' @return `fm_fem.fm_mesh_1d`: A list with elements `c0`, `c1`, `g1`, `g2`.
+#' @returns `fm_fem.fm_mesh_1d`: A list with elements `c0`, `c1`, `g1`, `g2`.
 #' When `mesh$degree == 2`, also `g01`, `g02`, and `g12`.
 #' @export
 fm_fem.fm_mesh_1d <- function(mesh, order = 2, ...) {
@@ -158,7 +158,8 @@ fm_fem.fm_mesh_1d <- function(mesh, order = 2, ...) {
         )),
         weights =
           c(knots.d * 8 / 9, knots.d * 5 / 9, knots.d * 5 / 9)^0.5,
-        derivatives = TRUE
+        derivatives = TRUE,
+        full = TRUE
       )
     c1 <- Matrix::t(info$A) %*% info$A
     g1 <- Matrix::t(info$dA) %*% info$dA
@@ -170,7 +171,15 @@ fm_fem.fm_mesh_1d <- function(mesh, order = 2, ...) {
 
     c0 <- Matrix::Diagonal(nrow(c1), Matrix::rowSums(c1))
 
-    return(list(c0 = c0, c1 = c1, g1 = g1, g2 = g2, g01 = g01, g02 = g02, g12 = g12))
+    return(list(
+      c0 = c0,
+      c1 = c1,
+      g1 = g1,
+      g2 = g2,
+      g01 = g01,
+      g02 = g02,
+      g12 = g12
+    ))
   } else {
     stop(paste("Mesh basis degree=", mesh$degree,
       " is not supported by fm_fem.fm_mesh_1d.",
@@ -182,13 +191,14 @@ fm_fem.fm_mesh_1d <- function(mesh, order = 2, ...) {
 }
 
 #' @rdname fm_fem
-#' @param aniso If non-NULL, a `list(gamma, v)`. Calculates anisotropic structure
-#' matrices (in addition to the regular) for \eqn{\gamma}{gamma} and \eqn{v}{v} for
-#' an anisotropic operator \eqn{\nabla\cdot H \nabla}{div H grad}, where
-#' \eqn{H=\gamma I + v v^\top}{H = gamma I + v v'}.
-#' Currently (2023-08-05) the fields need to be given per vertex.
-#' @return `fm_fem.fm_mesh_2d`: A list with elements `c0`, `c1`, `g1`, `va`, `ta`,
-#' and more if `order > 1`. When `aniso` is non-NULL, also `g1aniso` matrices, etc.
+#' @param aniso If non-NULL, a `list(gamma, v)`. Calculates anisotropic
+#'   structure matrices (in addition to the regular) for \eqn{\gamma}{gamma} and
+#'   \eqn{v}{v} for an anisotropic operator \eqn{\nabla\cdot H \nabla}{div H
+#'   grad}, where \eqn{H=\gamma I + v v^\top}{H = gamma I + v v'}. Currently
+#'   (2023-08-05) the fields need to be given per vertex.
+#' @returns `fm_fem.fm_mesh_2d`: A list with elements `c0`, `c1`, `g1`, `va`,
+#'   `ta`, and more if `order > 1`. When `aniso` is non-NULL, also `g1aniso`
+#'   matrices, etc.
 #'
 #' @export
 fm_fem.fm_mesh_2d <- function(mesh, order = 2,
@@ -227,7 +237,7 @@ fm_fem.inla.mesh <- function(mesh, order = 2, ...) {
 }
 
 #' @rdname fm_fem
-#' @return `fm_fem.fm_tensor`: A list with elements `cc`, `g1`, `g2`.
+#' @returns `fm_fem.fm_tensor`: A list with elements `cc`, `g1`, `g2`.
 #' @export
 fm_fem.fm_tensor <- function(mesh, order = 2, ...) {
   if (order > 2) {
