@@ -16,14 +16,14 @@
 #' @param ... `data.frame`, `sf`, or `SpatialPointsDataFrame` objects, each one
 #' usually obtained by a call to an [fm_int()] method.
 #' @param na.rm logical; if `TRUE`, the rows with weight `NA` from the
-#' non-overlapping full_join will be removed; if `FALSE`, set the undefined weights to `NA`.
-#' If `NULL` (default), act as `TRUE`, but warn if any elements needed removing.
-#' @param .blockwise logical; if `FALSE`, computes full tensor product integration.
-#' If `TRUE`, computes within-block tensor product integration (used internally
-#' by [fm_int()]).
-#' Default `FALSE`
-#' @return A `data.frame`, `sf`, or `SpatialPointsDataFrame` of multidimensional
-#' integration points and their weights
+#'   non-overlapping full_join will be removed; if `FALSE`, set the undefined
+#'   weights to `NA`. If `NULL` (default), act as `TRUE`, but warn if any
+#'   elements needed removing.
+#' @param .blockwise logical; if `FALSE`, computes full tensor product
+#'   integration. If `TRUE`, computes within-block tensor product integration
+#'   (used internally by [fm_int()]). Default `FALSE`
+#' @returns A `data.frame`, `sf`, or `SpatialPointsDataFrame` of
+#'   multidimensional integration points and their weights
 #'
 #' @examples
 #' \donttest{
@@ -53,7 +53,8 @@ fm_cprod <- function(..., na.rm = NULL, .blockwise = FALSE) {
 
   # Transform sp to sf
   # TODO make a test. and give a warning for NA non-overlapping outcome?
-  # check for each element, or on the subset, change only for sp anonymous function on lapply
+  # check for each element, or on the subset, change only for sp anonymous
+  # function on lapply
   ipl_sp <- vapply(ipl, function(x) inherits(x, "Spatial"), TRUE)
   ipl_sf <- vapply(ipl, function(x) inherits(x, c("sf", "sfc")), TRUE)
   ipl[ipl_sp] <- lapply(ipl[ipl_sp], sf::st_as_sf)
@@ -91,11 +92,13 @@ fm_cprod <- function(..., na.rm = NULL, .blockwise = FALSE) {
     }
 
     # `sf::st_join` performs spatial join/filter; `dplyr::*_join` expects `x` of
-    # class `sf` and `y` of class `data.frame`. The trick `as.tibble(sf_obj)` allows
-    # `dplyr::full_join` and turn it back to `sf` with active geometry as the ips1.
+    # class `sf` and `y` of class `data.frame`. The trick `as.tibble(sf_obj)`
+    # allows `dplyr::full_join` and turn it back to `sf` with active geometry as
+    # the ips1.
     # Z <- full_join(as_tibble(X), as_tibble(Y), by = "group")
     # st_as_sf(Z)
-    # https://stackoverflow.com/questions/64365792/dplyr-full-join-on-geometry-columns-of-sf-objects
+    # https://stackoverflow.com/questions/64365792/
+    #   dplyr-full-join-on-geometry-columns-of-sf-objects
     if (inherits(ips1, c("sf", "sfc")) ||
       inherits(ips2, c("sf", "sfc"))) {
       if (length(by) == 0) {
@@ -141,7 +144,8 @@ fm_cprod <- function(..., na.rm = NULL, .blockwise = FALSE) {
     if (is.null(na.rm)) {
       warning(
         paste0(
-          "Block information mismatch resulting in NA weights, and 'na.rm' was not supplied.",
+          "Block information mismatch resulting in NA weights,",
+          " and 'na.rm' was not supplied.",
           " These rows will be removed."
         )
       )
@@ -149,15 +153,21 @@ fm_cprod <- function(..., na.rm = NULL, .blockwise = FALSE) {
     ips <- na.omit(ips)
   }
 
-  # TODO Transform back to sp only if they are required. ips is a tibble sf tbl data.frame.
-  # It does not make sense to revert certain indices back after merging. Hence, I revert the entire object back to sp.
+  # TODO Transform back to sp only if they are required. ips is a tibble sf tbl
+  # data.frame.
+  # It does not make sense to revert certain indices back after merging. Hence,
+  # I revert the entire object back to sp.
   if (any(ipl_sp)) {
     ips <- sf::as_Spatial(ips)
     if (any(ipl_sf)) {
-      lifecycle::deprecate_soft(
+      lifecycle::deprecate_warn(
         when = "0.0.1",
         what = "fm_cprod('...'='should not mix `sp` and `sf` objects')",
-        details = c("Converting to `sp` since there was at least one `sp` input object.")
+        details =
+          paste0(
+            "Converting to `sp` since there was",
+            " at least one `sp` input object."
+          )
       )
     }
   }
@@ -170,17 +180,17 @@ fm_cprod <- function(..., na.rm = NULL, .blockwise = FALSE) {
 #' @description Construct integration points on tensor product spaces
 #' @param domain Functional space specification; single domain or a named list
 #' of domains
-#' @param samplers For single domain `fm_int` methods, an object specifying one or more
-#' subsets of the domain, and optional weighting in a `weight` variable.
-#' For `fm_int.list`, a list of sampling definitions, where data frame elements
-#' may contain information for multiple domains, in which case each row represent
-#' a separate tensor product integration subspace.
+#' @param samplers For single domain `fm_int` methods, an object specifying one
+#'   or more subsets of the domain, and optional weighting in a `weight`
+#'   variable. For `fm_int.list`, a list of sampling definitions, where data
+#'   frame elements may contain information for multiple domains, in which case
+#'   each row represent a separate tensor product integration subspace.
 #' @param name For single-domain methods, the variable name to use for the
 #' integration points. Default 'x'
 #' @param \dots Additional arguments passed on to other methods
 #'
-#' @returns A `data.frame`, `tibble`, `sf`, or `SpatialPointsDataFrame` of 1D and
-#' 2D integration points, including a `weight` column and `.block` column.
+#' @returns A `data.frame`, `tibble`, `sf`, or `SpatialPointsDataFrame` of 1D
+#'   and 2D integration points, including a `weight` column and `.block` column.
 
 #'
 #' @export
@@ -297,7 +307,10 @@ fm_int.list <- function(domain, samplers = NULL, ...) {
   sp_samplers <- unlist(lapply(samplers, function(x) inherits(x, "Spatial")))
   if (any(sp_samplers)) {
     if (any(sf_samplers)) {
-      warning("Both `sf` and `sp` objects in the samplers are detected. Output will be `sf`.")
+      warning(paste0(
+        "Both `sf` and `sp` objects in the samplers are detected.",
+        " Output will be `sf`."
+      ))
     }
     samplers[sp_samplers] <- lapply(samplers[sp_samplers], sf::st_as_sf)
     if (!("coordinates" %in% names(domain))) {
@@ -308,10 +321,13 @@ fm_int.list <- function(domain, samplers = NULL, ...) {
 
   # TODO 20220126 lapply to extract the names, the current one is not sufficient
   # TODO Sort multidomain samplers, single domain samplers
-  # TODO Multidomain samplers happens when a sampler across several domains. How to detect that?
+  # TODO Multidomain samplers happens when a sampler across several domains. How
+  # to detect that?
   # TODO we should then do the name check for domain and samplers here
   # TODO remove sampler domains and full domain samplers
-  # TODO some thoughts for S3 methods, there should be an extra layer ie function to sort samplers and domain arguments and difine multidomain, singledomain and full domain s3 class
+  # TODO some thoughts for S3 methods, there should be an extra layer ie
+  # function to sort samplers and domain arguments and difine multidomain,
+  # singledomain and full domain s3 class
   #######################
   names_domain <- names(domain)
   names_lsamplers <- names(samplers)
@@ -329,7 +345,8 @@ fm_int.list <- function(domain, samplers = NULL, ...) {
           stop(
             paste0(
               "Unnamed sampler in the samplers is an 'fm_segm' object.\n",
-              "Use an 'sf' object or other supported multi-sampler class instead."
+              "Use an 'sf' object or other supported",
+              " multi-sampler class instead."
             )
           )
           NULL
@@ -338,7 +355,8 @@ fm_int.list <- function(domain, samplers = NULL, ...) {
         }
       }
     )
-  names_reserved <- c("weight", ".block") # coordinate and geometry is not required here
+  # coordinate and geometry are not required here
+  names_reserved <- c("weight", ".block")
 
   if (length(intersect(names_domain, names_reserved)) > 0) {
     stop(paste0(
@@ -351,11 +369,14 @@ fm_int.list <- function(domain, samplers = NULL, ...) {
   lips_samplers <- list()
 
   #######################
-  # multidomain samplers, ie unnamed element(s) in samplers, for each sampler and then for each domain(lapply)
+  # multidomain samplers, ie unnamed element(s) in samplers, for each sampler
+  # and then for each domain(lapply)
   # TODO still have to deal with secondary geometry
   for (i in index_multi_samplers) {
     if (is.null(names_samplers[[i]])) {
-      stop(paste0("The unnamed sampler #", i, " in the samplers has no sub-names."))
+      stop(paste0(
+        "The unnamed sampler #", i, " in the samplers has no sub-names."
+      ))
     }
     lips_samplers[[i]] <-
       fm_int_multi_sampler(
@@ -370,7 +391,13 @@ fm_int.list <- function(domain, samplers = NULL, ...) {
   for (i in index_single_samplers) {
     nm <- intersect(names_samplers[[i]], names_domain)
     if (length(nm) == 0) {
-      stop(paste0("The named sampler '", names_lsamplers[[i]], "' in the samplers has no corresponding domain."))
+      stop(
+        paste0(
+          "The named sampler '",
+          names_lsamplers[[i]],
+          "' in the samplers has no corresponding domain."
+        )
+      )
     }
     lips_samplers[[i]] <-
       fm_int(
@@ -549,7 +576,11 @@ fm_int.fm_lattice_2d <- function(domain, samplers = NULL, name = "x", ...) {
 #' )
 #' plot(ips$x, ips$weight)
 #'
-fm_int.fm_mesh_1d <- function(domain, samplers = NULL, name = "x", int.args = NULL, ...) {
+fm_int.fm_mesh_1d <- function(domain,
+                              samplers = NULL,
+                              name = "x",
+                              int.args = NULL,
+                              ...) {
   int.args.default <- list(method = "stable", nsub1 = 30, nsub2 = 9)
   if (is.null(int.args)) {
     int.args <- list()
@@ -604,7 +635,8 @@ fm_int.fm_mesh_1d <- function(domain, samplers = NULL, name = "x", int.args = NU
       } else {
         subsampler[1] <- domain$interval[1] +
           (subsampler[1] - domain$interval[1]) %% diff(domain$interval)
-        subsampler[2] <- subsampler[1] + diff(subsampler) %% diff(domain$interval)
+        subsampler[2] <- subsampler[1] +
+          diff(subsampler) %% diff(domain$interval)
         if (diff(subsampler) == 0.0) {
           subsampler <- domain$interval
         } else if (subsampler[2] > domain$interval[2]) {
@@ -766,11 +798,12 @@ fm_int.fm_mesh_2d <- function(domain,
 #' @title Project integration points to mesh vertices
 #'
 #' @description
-#' Compute information for assigning points to the vertices of the covering triangle
+#' Compute information for assigning points to the vertices of the covering
+#' triangle
 #'
 #' @param points A `SpatialPointsDataFrame`, `sf`, or `list` object
 #' @param mesh An `fm_mesh_2d` or `inla.mesh` object
-#' @return `SpatialPointsDataFrame`, `sf`, or `list` of mesh vertices with
+#' @returns `SpatialPointsDataFrame`, `sf`, or `list` of mesh vertices with
 #' projected data attached
 #' @importFrom rlang .data
 #' @keywords internal
@@ -801,7 +834,12 @@ fm_vertex_projection <- function(points, mesh) {
   ok <- !is.na(tri)
   ok[ok] <- (tri[ok] > 0)
   if (any(!ok)) {
-    warning("Some integration points were outside the mesh; check your coordinate systems.")
+    warning(
+      paste0(
+        "Some integration points were outside the mesh;",
+        " check your coordinate systems."
+      )
+    )
   }
 
   data <-
@@ -821,6 +859,7 @@ fm_vertex_projection <- function(points, mesh) {
   data <- dplyr::select(data, c("weight", ".block", ".vertex"))
 
   if (inherits(points, "Spatial")) {
+    fm_safe_sp(force = TRUE)
     ret <- sp::SpatialPointsDataFrame(
       coords[, seq_len(min(
         ncol(coords),
@@ -833,7 +872,9 @@ fm_vertex_projection <- function(points, mesh) {
     sp::coordnames(ret) <- sp::coordnames(points)
   } else if (inherits(points, "sf")) {
     colnames(coords) <- c("X", "Y", "Z")[seq_len(ncol(coords))]
-    d <- min(ncol(coords), length(intersect(colnames(sf::st_coordinates(points)), c("X", "Y", "Z"))))
+    d <- min(ncol(coords), length(intersect(
+      colnames(sf::st_coordinates(points)), c("X", "Y", "Z")
+    )))
     data <- cbind(
       tibble::as_tibble(coords[, seq_len(d), drop = FALSE]),
       tibble::as_tibble(data)
@@ -1072,13 +1113,21 @@ fm_int_mesh_2d_lines <- function(samplers,
 
     ips <- fm_transform(mp3d, crs = target_crs, crs0 = geocentric.crs)
     w <- sp::spDists(
-      fm_transform(sp3d, crs = longlat.crs, crs0 = geocentric.crs)[, 1:2, drop = FALSE],
-      fm_transform(ep3d, crs = longlat.crs, crs0 = geocentric.crs)[, 1:2, drop = FALSE],
-      diagonal = TRUE, longlat = TRUE
+      fm_transform(sp3d,
+        crs = longlat.crs,
+        crs0 = geocentric.crs
+      )[, 1:2, drop = FALSE],
+      fm_transform(ep3d,
+        crs = longlat.crs,
+        crs0 = geocentric.crs
+      )[, 1:2, drop = FALSE],
+      diagonal = TRUE,
+      longlat = TRUE
     )
   }
 
-  # Wrap everything up and perform projection according to distance and given .block argument
+  # Wrap everything up and perform projection according to distance and given
+  # .block argument
   ips <- data.frame(ips)
   d_ips <- ncol(ips)
   # Temporary names
@@ -1152,7 +1201,7 @@ fm_int_mesh_2d.sfc_MULTILINESTRING <- function(samplers,
 #'    `(nsub + 1)^2` proto-integration points used to compute
 #'   the vertex weights
 #'   (default `nsub=9`, giving 100 integration points for each triangle)
-#' @return `list` with elements `loc` and `weight` with
+#' @returns `list` with elements `loc` and `weight` with
 #'   integration points for the mesh
 #' @author Finn Lindgren \email{finn.lindgren@@gmail.com}
 #' @keywords internal
@@ -1481,7 +1530,11 @@ fm_int.inla.mesh.lattice <- function(domain, samplers = NULL, name = "x", ...) {
 
 #' @rdname fm_int
 #' @export
-fm_int.inla.mesh.1d <- function(domain, samplers = NULL, name = "x", int.args = NULL, ...) {
+fm_int.inla.mesh.1d <- function(domain,
+                                samplers = NULL,
+                                name = "x",
+                                int.args = NULL,
+                                ...) {
   fm_int.fm_mesh_1d(
     fm_as_mesh_1d(domain),
     samplers = samplers,
