@@ -1,3 +1,11 @@
+/*
+ *  Copyright Finn Lindgren (2010-2024)
+ *
+ *  This Source Code Form is subject to the terms of the Mozilla Public License,
+ *  v. 2.0. If a copy of the MPL was not distributed with this file, You can
+ *  obtain one at https://mozilla.org/MPL/2.0/.
+ */
+
 #ifndef _FMESH_MESH_
 #define _FMESH_MESH_ 1
 
@@ -45,6 +53,7 @@ class Mesh {
 
 public:
   enum class Mtype : int { Manifold = 0, Plane, Sphere };
+  friend std::ostream &operator<<(std::ostream &output, const Mesh::Mtype &type);
 
 private:
   Mtype type_;
